@@ -12,6 +12,13 @@ from string import ascii_lowercase as LC, ascii_uppercase as UC
 from ..__common__ import *
 
 
+__examples__ = {
+    'enc(rot0|rot--10|rot100)':               None,
+    'enc(rot1|rot-1|rot_1|ROT1|ROT-1|ROT_1)': {'this is a test': "uijt jt b uftu"},
+    'enc(rot3)':                              {'this is a test': "wklv lv d whvw"},
+}
+
+
 def _rotn(text, n=13):
     n = n % 26
     t = maketrans(LC + UC, LC[n:] + LC[:n] + UC[n:] + UC[:n])
