@@ -1,5 +1,6 @@
 # -*- coding: UTF-8 -*-
 from .leetspeak import *
-from .nokia import *
 from .resistor import *
+from .sms import *
 from .whitespace import *
+
