@@ -10,6 +10,12 @@ This codec:
 from ..__common__ import *
 
 
+__examples__ = {
+    'enc(leet|1337|leetspeak)': {'this is a test': "7h15 15 4 7357"},
+    'dec(leet|1337|leetspeak)': {'7H15 15 4 7357': "THIS IS A TEST"},
+}
+
+
 ENCMAP = {k: v for k, v in zip("abeiostABEIOSTZ", "483105748310572")}
 
 
