@@ -10,6 +10,14 @@ This codec:
 from ..__common__ import *
 
 
+__examples__ = {
+    'enc(resistor_color)': {'test': None},
+    'enc(resistor|resistor_color|resistor_color_code|resistors-color-code)': {
+        '1234': "\x1b[48;5;130m \x1b[0;00m\x1b[48;5;1m \x1b[0;00m\x1b[48;5;214m \x1b[0;00m\x1b[48;5;11m \x1b[0;00m"
+    },
+}
+
+
 ENCMAP = {i: "\033[48;5;%dm \033[0;00m" % c for i, c in zip("0123456789", [232, 130, 1, 214, 11, 2, 4, 129, 245, 231])}
 ENCMAP[' '] = "/"
 
